'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _connection = require('../plugins/db/connection');

var _control = require('../plugins/db/control');

var _log = require('./log');

var _cache = require('./cache');

exports.default = async function (context, tipo) {
  try {
    let con = (0, _connection.Connection)(context.config, { logging: text => {
        if (context.config.showSql) console.log(text);
        (0, _log.addDbLog)(context.config, text);
      } });

    let cache = {};
    let models = { con };
    let modules = {};
    let migrations = [];
    let seeds = [];
    let scripts = [];

    // Percorre os modulos
    Object.keys(context.modules).forEach(i => {
      let modulo = context.modules[i];

      // Pega as migrations
      let migrationItens = modulo.db && modulo.db.migrations ? modulo.db.migrations : [];
      migrations.push(...migrationItens);

      // Pega os models
      let modelItens = modulo.db && modulo.db.models ? modulo.db.models : {};
      Object.keys(modelItens).forEach(x => {
        models[x] = modelItens[x](con);
        if (!modules[i]) modules[i] = { models: [] };
        modules[i].models.push(x);
        if (context.config.cache.enable) cache[x] = new _cache.CacheControl(context.config, x);
      });

      // Pega os seeds
      let seedItens = modulo.db && modulo.db.seeds ? modulo.db.seeds : [];
      seeds.push(...seedItens);

      // Pega os seeds
      let scriptItens = modulo.db && modulo.db.scripts ? modulo.db.scripts : [];
      scripts.push(...scriptItens);
    });

    // Percorre os models para criar associacoes
    Object.keys(models).forEach(e => {
      if (models[e].associate) models[e].associate(models);
      if (models[e].methods) models[e].methods(models);
    });

    return {
      cache,
      models,
      modules,
      async execute() {
        // Clean Cache
        if (context.config.cache.enable) await (0, _cache.cleanCache)(context.config);
        // Controle de Execução
        const controle = new _control.ExecuteControl(con, tipo);
        controle.setItens(migrations, seeds, scripts, models);
        await controle.exec();
      }
    };
  } catch (e) {
    console.error(e);
    throw e;
  }
};
//# sourceMappingURL=create.js.map