'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addErrorLog = addErrorLog;
exports.addLog = addLog;
exports.addServiceLog = addServiceLog;
exports.addDbLog = addDbLog;

var _mongodb = require('mongodb');

var _request = require('../util/request');

function addErrorLog(config, error) {
  (0, _request.errorMessage)(error);
  _mongodb.MongoClient.connect(config.mongo.url, { useNewUrlParser: true }, (err, client) => {
    if (!err) {
      const db = client.db(config.mongo.db);
      const errorLog = db.collection('errorlogs');
      errorLog.insert({
        message: JSON.stringify(error)
      });
      client.close();
    }
  });
}

function addLog(config, req, result, data) {
  if (!config.log) return false;

  req.agent = (0, _request.getClientInfo)(req);
  _mongodb.MongoClient.connect(config.mongo.url, { useNewUrlParser: true }, (err, client) => {
    if (!err) {
      const db = client.db(config.mongo.db);
      const logs = db.collection('logs');
      data = data || {};
      logs.insert({
        createdAt: new Date(),
        url: req.originalUrl,
        result,
        request: JSON.parse(JSON.stringify({
          headers: req.headers,
          body: req.body,
          query: req.query,
          params: req.params,
          agent: req.agent
        })),
        response: JSON.parse(JSON.stringify(data))
      }, (err, result) => {
        if (err) throw err;
      });
      client.close();
    }
  });
}

function addServiceLog(config, result, data) {
  if (!config.log) return false;

  _mongodb.MongoClient.connect(config.mongo.url, { useNewUrlParser: true }, (err, client) => {
    if (!err) {
      const db = client.db(config.mongo.db);
      const logs = db.collection('logs');
      data = data || {};
      logs.insert({
        createdAt: new Date(),
        result,
        response: JSON.parse(JSON.stringify(data))
      }, (err, result) => {
        if (err) throw err;
      });
      client.close();
    }
  });
}

function addDbLog(config, text) {
  if (config.log) {
    _mongodb.MongoClient.connect(config.mongo.url, { useNewUrlParser: true }, function (err, client) {
      if (!err) {
        const db = client.db(config.mongo.db);
        const logs = db.collection('mysqllogs');

        logs.insert({ createdAt: Date.now(), text });
        client.close();
      }
    });
  }
}
//# sourceMappingURL=log.js.map