'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (context, controllers, mixins) {
  // Cria instancia do express
  let app = (0, _express2.default)();
  // Morgan console
  if (context.config.server.morgan) {
    app.use(require('morgan')('tiny'));
  }

  // Inicia o server
  const server = (0, _http.createServer)(app);
  // Timeout da config
  server.timeout = context.config.server.timeout;

  // Conexão via socket
  let io = null;
  if (context.config.socket.enable) {
    let io = (0, _socket2.default)(server);
    io.set('transports', ['websocket']);
    io.adapter((0, _socket4.default)({ host: context.config.socket.redis.host, port: context.config.socket.redis.port }));
  }

  // Middlewares de segurança e transformação
  app.use((0, _cors2.default)());
  app.use(_bodyParser2.default.urlencoded({ limit: '500mb', extended: true }));
  app.use(_bodyParser2.default.json({ limit: '500mb' }));
  app.use(_helmet2.default.frameguard());
  app.use(_helmet2.default.xssFilter());
  app.use(_helmet2.default.noSniff());
  app.use(_helmet2.default.ieNoOpen());
  app.disable('x-powered-by');

  // Pasta Statica
  app.use('/static', _express2.default.static((0, _path.join)(context.config.dirname, './static')));
  // Pasta de imagens/arquivos publicas
  app.use('/public', _express2.default.static((0, _path.join)(context.config.dirname, './files/public')));

  // Express Join IO
  app.io = io;
  // Pre Flight Enable
  app.options('*', (0, _cors2.default)());
  // Routes
  app = (0, _modules.startRoute)(app, context, controllers, mixins);

  // Rotas não encontradas
  function err(req, res) {
    return res.status(404).json({ error: 'Método não encontrado!' });
  }

  app.get('*', err);
  app.post('*', err);
  app.put('*', err);
  app.delete('*', err);
  return { app, server };
};

var _http = require('http');

var _path = require('path');

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _bodyParser = require('body-parser');

var _bodyParser2 = _interopRequireDefault(_bodyParser);

var _helmet = require('helmet');

var _helmet2 = _interopRequireDefault(_helmet);

var _cors = require('cors');

var _cors2 = _interopRequireDefault(_cors);

var _socket = require('socket.io');

var _socket2 = _interopRequireDefault(_socket);

var _socket3 = require('socket.io-redis');

var _socket4 = _interopRequireDefault(_socket3);

var _modules = require('./modules');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
//# sourceMappingURL=app.js.map