'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getObjects = getObjects;
exports.updateDB = updateDB;
exports.initServices = initServices;
exports.initRest = initRest;
exports.initRestAndService = initRestAndService;

var _cluster = require('cluster');

var _cluster2 = _interopRequireDefault(_cluster);

var _app = require('./app');

var _app2 = _interopRequireDefault(_app);

var _db = require('../db/');

var _db2 = _interopRequireDefault(_db);

var _modules = require('./modules');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let dbExecuted = false;
let globalExecute = false;

async function getObjects(context) {
  let { cache, models, modules, execute } = await (0, _db2.default)(context);
  context.cache = cache;
  const { controllers, mixins } = (0, _modules.createControllerAndMixins)(context, models, modules);
  globalExecute = execute;
  return { models, modules, execute, controllers, mixins, context };
}

async function updateDB() {
  if (!dbExecuted && globalExecute) {
    if (_cluster2.default.isMaster) {
      await globalExecute();
      dbExecuted = true;
    }
  }
}

async function initServices(objects) {
  return _cluster2.default.isMaster ? (0, _modules.startService)(objects.context, objects.controllers, objects.mixins) : null;
}

async function initRest(objects) {
  if (_cluster2.default.isMaster && objects.context.config.process === 'multiple' && objects.context.config.numProcess > 1) {
    for (let i = 0; i < objects.context.config.numProcess; i++) _cluster2.default.fork();
  } else {
    let instance = (0, _app2.default)(objects.context, objects.controllers, objects.mixins);
    instance.app.set('port', objects.context.config.server.port);
    instance.server.listen(objects.context.config.server.port, () => console.log(`Server iniciado ID#${_cluster2.default.worker ? _cluster2.default.worker.id : '0'} PID#${process.pid} escutando em http://localhost::${objects.context.config.server.port}`));
  }
}

async function initRestAndService(objects) {
  await updateDB();
  await initServices(objects);
  return initRest(objects);
}
//# sourceMappingURL=index.js.map