'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createControllerAndMixins = createControllerAndMixins;
exports.startService = startService;
exports.startRoute = startRoute;

var _functions = require('./functions');

var _rest = require('./rest');

var _service = require('./service');

function createControllerAndMixins(context, models, modules) {
  let controllers = {};
  let mixins = {};
  Object.keys(context.modules).forEach(k => {
    controllers[k] = (0, _functions.controller)(context.modules[k].controller, k, context, models, modules);
    mixins[k] = (0, _functions.mixin)(context.modules[k].mixins, k, mixins, context, models, modules);
  });
  return { controllers, mixins };
}

function startService(context, controllers, mixins) {
  const service = (0, _service.ctrlService)(mixins, context.config);
  Object.keys(context.modules).forEach(k => {
    if (context.modules[k].services) {
      context.modules[k].services({
        service,
        controller: controllers[k],
        others: controllers
      });
    }
  });
}

function startRoute(app, context, controllers, mixins) {
  // Seta Rest
  const route = (0, _rest.rest)(app, mixins, context.config);
  Object.keys(context.modules).forEach(k => {
    if (context.modules[k].rest) {
      context.modules[k].rest({
        route,
        controller: controllers[k],
        others: controllers
      });
    }
  });

  return app;
}
//# sourceMappingURL=modules.js.map